ConnectivityAdapter class abstract
连接类型数据源抽象 / Abstraction over the platform connectivity source.
默认由 connectivity_plus 实现,单元测试可注入假实现 /
Implemented by connectivity_plus by default; unit tests can inject fakes.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onConnectivityChanged
→ Stream<
List< String> > -
监听连接类型变化 / Emits whenever the transports change.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkConnectivity(
) → Future< List< String> > -
读取当前连接类型(如
['wifi'])/ Reads the current transports, e.g.['wifi']. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited