DnsAnswer class

单条 DNS 应答记录 / A single DNS answer record.

Constructors

DnsAnswer({required String name, required int type, required int ttl, required String value})
构造 DnsAnswer / Creates a DnsAnswer.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
记录所属域名 / Owner name of the record.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ttl int
生存时间,单位秒 / Time to live in seconds.
final
type int
记录类型,见 DnsRecordType / Record type, see DnsRecordType.
final
value String
记录值(A/AAAA 为地址字符串,CNAME 为目标域名)/ Record value: an address string for A/AAAA, a domain for CNAME.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited