DnsResponse class
解析后的 DNS 响应 / A parsed DNS response message.
Constructors
-
DnsResponse({required int id, required int responseCode, required List<
DnsAnswer> answers, bool truncated = false}) -
构造 DnsResponse / Creates a DnsResponse.
const
Properties
-
addresses
→ List<
String> -
A / AAAA 记录中的地址列表 / Address values extracted from A and AAAA records.
no setter
-
answers
→ List<
DnsAnswer> -
应答记录列表 / Answer records.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
事务 ID / Transaction id echoed from the query.
final
- isSuccess → bool
-
是否解析成功 / Whether the server answered successfully.
no setter
- responseCode → int
-
响应码,0 表示成功 / Response code, 0 means success.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- truncated → bool
-
是否被截断 / Whether the response was truncated.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited