NetworkQualityEvaluator class
网络质量评分器 / Composite network quality scorer.
纯函数实现,不产生任何 IO,方便单元测试与自定义权重 / Pure functions with no IO, which keeps it unit-testable and reusable.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited